`xl_comment()` builds a comment (note) that can be attached to a cell via
[xl_cell_general()]'s `comment` argument. The simplest form is just text
(`xl_cell_general(value = x, comment = "see note")`); `xl_comment()` adds
options such as the author, initial visibility, box size and position, and
styling.
Excel comment boxes support only a **background color** and a **font
name/size/family**. These are supplied by reusing the formatting engine via
the `format` argument (e.g. `xl_font(name = "Arial", size = 10) +
xl_fill(background = "lightyellow")`); any other format property (bold,
borders, number formats, ...) is not supported by comments and triggers a
warning.